import { ComponentType } from 'react';
import { IReactionPublic, IReactionOptions, IReactionDisposer } from '@alilc/lowcode-editor-core';
import { IPublicTypeProjectSchema, IPublicTypeComponentMetadata, IPublicTypeComponentAction, IPublicTypeNpmInfo, IPublicModelEditor, IPublicTypeCompositeObject, IPublicTypePropsList, IPublicTypeNodeSchema, IPublicTypePropsTransducer, IShellModelFactory, IPublicModelDragObject, IPublicModelScrollable, IDesigner, IPublicModelScroller, IPublicTypeLocationData, IPublicEnumTransformStage } from '@alilc/lowcode-types';
import { IPublicTypeAssetsJson } from '@alilc/lowcode-utils';
import { Project } from '../project';
import { Node, DocumentModel, INode } from '../document';
import { ComponentMeta } from '../component-meta';
import { INodeSelector, Component } from '../simulator';
import { Dragon, ILocateEvent } from './dragon';
import { ActiveTracker } from './active-tracker';
import { Detecting } from './detecting';
import { DropLocation } from './location';
import { OffsetObserver } from './offset-observer';
import { SettingTopEntry } from './setting';
import { BemToolsManager } from '../builtin-simulator/bem-tools/manager';
export interface DesignerProps {
    editor: IPublicModelEditor;
    shellModelFactory: IShellModelFactory;
    className?: string;
    style?: object;
    defaultSchema?: IPublicTypeProjectSchema;
    hotkeys?: object;
    simulatorProps?: object | ((document: DocumentModel) => object);
    simulatorComponent?: ComponentType<any>;
    dragGhostComponent?: ComponentType<any>;
    suspensed?: boolean;
    componentMetadatas?: IPublicTypeComponentMetadata[];
    globalComponentActions?: IPublicTypeComponentAction[];
    onMount?: (designer: Designer) => void;
    onDragstart?: (e: ILocateEvent) => void;
    onDrag?: (e: ILocateEvent) => void;
    onDragend?: (e: {
        dragObject: IPublicModelDragObject;
        copy: boolean;
    }, loc?: DropLocation) => void;
    viewName?: string;
    [key: string]: any;
}
export declare class Designer implements IDesigner {
    readonly dragon: Dragon;
    readonly activeTracker: ActiveTracker;
    readonly detecting: Detecting;
    readonly project: Project;
    readonly editor: IPublicModelEditor;
    readonly bemToolsManager: BemToolsManager;
    readonly shellModelFactory: IShellModelFactory;
    get currentDocument(): import("@alilc/lowcode-types").IPublicModelDocumentModel;
    get currentHistory(): import("@alilc/lowcode-types").IPublicModelHistory;
    get currentSelection(): import("@alilc/lowcode-types").IPublicModelSelection;
    viewName: string | undefined;
    constructor(props: DesignerProps);
    setupSelection: () => void;
    postEvent(event: string, ...args: any[]): void;
    private _dropLocation?;
    get dropLocation(): DropLocation;
    /**
     * 创建插入位置，考虑放到 dragon 中
     */
    createLocation(locationData: IPublicTypeLocationData): DropLocation;
    /**
     * 清除插入位置
     */
    clearLocation(): void;
    createScroller(scrollable: IPublicModelScrollable): IPublicModelScroller;
    private oobxList;
    createOffsetObserver(nodeInstance: INodeSelector): OffsetObserver | null;
    private clearOobxList;
    touchOffsetObserver(): void;
    createSettingEntry(nodes: Node[]): SettingTopEntry;
    /**
     * 获得合适的插入位置
     */
    getSuitableInsertion(insertNode?: INode | IPublicTypeNodeSchema | IPublicTypeNodeSchema[]): {
        target: INode;
        index?: number;
    } | null;
    private props?;
    setProps(nextProps: DesignerProps): void;
    loadIncrementalAssets(incrementalAssets: IPublicTypeAssetsJson): Promise<void>;
    /**
     * 刷新 componentMetasMap，可间接触发模拟器里的 buildComponents
     */
    refreshComponentMetasMap(): void;
    get(key: string): any;
    private _simulatorComponent?;
    get simulatorComponent(): ComponentType<any> | undefined;
    private _simulatorProps?;
    get simulatorProps(): object;
    /**
     * 提供给模拟器的参数
     */
    get projectSimulatorProps(): any;
    private _suspensed;
    get suspensed(): boolean;
    set suspensed(flag: boolean);
    get schema(): IPublicTypeProjectSchema;
    setSchema(schema?: IPublicTypeProjectSchema): void;
    private _componentMetasMap;
    private _lostComponentMetasMap;
    buildComponentMetasMap(metas: IPublicTypeComponentMetadata[]): void;
    createComponentMeta(data: IPublicTypeComponentMetadata): ComponentMeta;
    getGlobalComponentActions(): IPublicTypeComponentAction[] | null;
    getComponentMeta(componentName: string, generateMetadata?: () => IPublicTypeComponentMetadata | null): ComponentMeta;
    getComponentMetasMap(): Map<string, ComponentMeta>;
    get componentsMap(): {
        [key: string]: IPublicTypeNpmInfo | Component;
    };
    private propsReducers;
    transformProps(props: IPublicTypeCompositeObject | IPublicTypePropsList, node: Node, stage: IPublicEnumTransformStage): IPublicTypeCompositeObject | IPublicTypePropsList;
    addPropsReducer(reducer: IPublicTypePropsTransducer, stage: IPublicEnumTransformStage): void;
    autorun(effect: (reaction: IReactionPublic) => void, options?: IReactionOptions): IReactionDisposer;
    purge(): void;
}
