import { Node, INode } from './node';
import { IPublicTypeNodeData, IPublicModelNodeChildren, IPublicEnumTransformStage } from '@alilc/lowcode-types';
import { NodeRemoveOptions } from '../../types';
export interface IOnChangeOptions {
    type: string;
    node: Node;
}
export interface INodeChildren extends IPublicModelNodeChildren {
}
export declare class NodeChildren implements INodeChildren {
    readonly owner: INode;
    private children;
    private emitter;
    constructor(owner: INode, data: IPublicTypeNodeData | IPublicTypeNodeData[], options?: any);
    internalInitParent(): void;
    /**
     * 导出 schema
     */
    export(stage?: IPublicEnumTransformStage): IPublicTypeNodeData[];
    import(data?: IPublicTypeNodeData | IPublicTypeNodeData[], checkId?: boolean): void;
    /**
     * @deprecated
     * @param nodes
     */
    concat(nodes: INode[]): INode[];
    /**
     * 元素个数
     */
    get size(): number;
    /**
     * 是否空
     */
    isEmpty(): boolean;
    notEmpty(): boolean;
    get length(): number;
    private purged;
    /**
     * 回收销毁
     */
    purge(useMutator?: boolean): void;
    unlinkChild(node: INode): boolean;
    /**
     * 删除一个节点
     */
    delete(node: INode, purge?: boolean, useMutator?: boolean, options?: NodeRemoveOptions): boolean;
    /**
     * 插入一个节点，返回新长度
     */
    insert(node: INode, at?: number | null, useMutator?: boolean): void;
    /**
     * 取得节点索引编号
     */
    indexOf(node: INode): number;
    /**
     *
     */
    splice(start: number, deleteCount: number, node?: INode): INode[];
    /**
     * 根据索引获得节点
     */
    get(index: number): INode | null;
    /**
     * 是否存在节点
     */
    has(node: INode): boolean;
    /**
     * 迭代器
     */
    [Symbol.iterator](): {
        next(): {
            value: INode;
        };
    };
    /**
     * 遍历
     */
    forEach(fn: (item: INode, index: number) => void): void;
    /**
     * 遍历
     */
    map<T>(fn: (item: INode, index: number) => T): T[] | null;
    every(fn: (item: INode, index: number) => any): boolean;
    some(fn: (item: INode, index: number) => any): boolean;
    filter(fn: (item: INode, index: number) => any): INode[];
    find(fn: (item: INode, index: number) => boolean): INode;
    reduce(fn: (acc: any, cur: INode) => any, initialValue: any): void;
    mergeChildren(remover: (node: INode, idx: number) => boolean, adder: (children: INode[]) => IPublicTypeNodeData[] | null, sorter: (firstNode: INode, secondNode: INode) => number): any;
    onChange(fn: (info?: IOnChangeOptions) => void): () => void;
    onInsert(fn: (node: INode) => void): () => void;
    get [Symbol.toStringTag](): string;
    private reportModified;
}
