import { Designer } from '../designer';
import { DocumentModel } from '../document';
import { IPublicTypeProjectSchema, IPublicTypeRootSchema, IPublicApiProject, IPublicModelDocumentModel, IPublicEnumTransformStage } from '@alilc/lowcode-types';
import { ISimulatorHost } from '../simulator';
export interface IProject extends IPublicApiProject {
}
export declare class Project implements IProject {
    readonly designer: Designer;
    readonly viewName: string;
    private emitter;
    readonly documents: IPublicModelDocumentModel[];
    private data;
    private _simulator?;
    /**
     * 模拟器
     */
    get simulator(): ISimulatorHost | null;
    key: number;
    constructor(designer: Designer, schema?: IPublicTypeProjectSchema, viewName?: string);
    get currentDocument(): IPublicModelDocumentModel;
    private _config;
    get config(): any;
    set config(value: any);
    private _i18n;
    get i18n(): any;
    set i18n(value: any);
    private getComponentsMap;
    /**
     * 获取项目整体 schema
     */
    getSchema(stage?: IPublicEnumTransformStage): IPublicTypeProjectSchema;
    /**
     * 替换当前 document 的 schema，并触发渲染器的 render
     * @param schema
     */
    setSchema(schema?: IPublicTypeProjectSchema): void;
    /**
     * 整体设置项目 schema
     *
     * @param autoOpen true 自动打开文档 string 指定打开的文件
     */
    load(schema?: IPublicTypeProjectSchema, autoOpen?: boolean | string): void;
    /**
     * 卸载当前项目数据
     */
    unload(): void;
    removeDocument(doc: IPublicModelDocumentModel): void;
    /**
     * 分字段设置储存数据，不记录操作记录
     */
    set(key: 'version' | 'componentsTree' | 'componentsMap' | 'utils' | 'constants' | 'i18n' | 'css' | 'dataSource' | string, value: any): void;
    /**
     * 分字段设置储存数据
     */
    get(key: 'version' | 'componentsTree' | 'componentsMap' | 'utils' | 'constants' | 'i18n' | 'css' | 'dataSource' | 'config' | string): any;
    private documentsMap;
    getDocument(id: string): DocumentModel | null;
    getDocumentByFileName(fileName: string): DocumentModel | null;
    createDocument(data?: IPublicTypeRootSchema): DocumentModel;
    open(doc?: string | DocumentModel | IPublicTypeRootSchema): DocumentModel | null;
    checkExclusive(activeDoc: DocumentModel): void;
    closeOthers(opened: DocumentModel): void;
    mountSimulator(simulator: ISimulatorHost): void;
    setRendererReady(renderer: any): void;
    onSimulatorReady(fn: (args: any) => void): () => void;
    onRendererReady(fn: (args: any) => void): () => void;
    onCurrentDocumentChange(fn: (doc: DocumentModel) => void): () => void;
}
